@@ -1,6 +1,6 @@
 package PDL::NDBin::Action::StdDev;
 {
-  $PDL::NDBin::Action::StdDev::VERSION = '0.012';
+  $PDL::NDBin::Action::StdDev::VERSION = '0.013';
 }
 # ABSTRACT: Action for PDL::NDBin that computes standard deviation
 
@@ -28,7 +28,7 @@ sub process
 	my $self = shift;
 	my $iter = shift;
 	$self->{out} = PDL->zeroes( $self->{type}, $self->{N} ) unless defined $self->{out};
-	$self->{count} = PDL->zeroes( PDL::long, $self->{N} ) unless defined $self->{count};
+	$self->{count} = PDL->zeroes( defined(&PDL::indx) ? PDL::indx() : PDL::long, $self->{N} ) unless defined $self->{count};
 	# as the internal computations happen in double, the type of 'avg' sticks to double
 	$self->{avg} = PDL->zeroes( PDL::double, $self->{N} ) unless defined $self->{avg};
 	PDL::NDBin::Actions_PP::_istddev_loop( $iter->data, $iter->idx, $self->{out}, $self->{count}, $self->{avg}, $self->{N} );
@@ -42,7 +42,7 @@ sub process
 sub result
 {
 	my $self = shift;
-	PDL::NDBin::Actions_PP::_istddev_post( $self->{count}, $self->{out} );
+	$self->{out}->inplace->_istddev_post( $self->{count} );
 	return $self->{out};
 }
 
@@ -52,13 +52,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 PDL::NDBin::Action::StdDev - Action for PDL::NDBin that computes standard deviation
 
 =head1 VERSION
 
-version 0.012
+version 0.013
 
 =head1 DESCRIPTION
 
