@@ -1,6 +1,6 @@
 package PDL::NDBin::Action::Sum;
 {
-  $PDL::NDBin::Action::Sum::VERSION = '0.012';
+  $PDL::NDBin::Action::Sum::VERSION = '0.013';
 }
 # ABSTRACT: Action for PDL::NDBin that computes sum
 
@@ -34,7 +34,7 @@ sub process
 		}
 		$self->{out} = PDL->zeroes( $type, $self->{N} );
 	}
-	$self->{count} = PDL->zeroes( PDL::long, $self->{N} ) unless defined $self->{count};
+	$self->{count} = PDL->zeroes( defined(&PDL::indx) ? PDL::indx() : PDL::long, $self->{N} ) unless defined $self->{count};
 	PDL::NDBin::Actions_PP::_isum_loop( $iter->data, $iter->idx, $self->{out}, $self->{count}, $self->{N} );
 	# as the plugin processes all bins at once, every variable
 	# needs to be visited only once
@@ -46,7 +46,7 @@ sub process
 sub result
 {
 	my $self = shift;
-	PDL::NDBin::Actions_PP::_setnulltobad( $self->{count}, $self->{out} );
+	$self->{out}->inplace->_setnulltobad( $self->{count} );
 	return $self->{out};
 }
 
@@ -56,13 +56,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 PDL::NDBin::Action::Sum - Action for PDL::NDBin that computes sum
 
 =head1 VERSION
 
-version 0.012
+version 0.013
 
 =head1 DESCRIPTION
 
